@@ -16,6 +16,7 @@ class Strategy(object):
         self.__handle_trade = scope.get('on_trade', None)
         self.__handle_open = scope.get('on_open', None)
         self.__handle_close = scope.get('on_close', None)
+        self.__handle_market_close = scope.get('on_market_close', None)
 
         if self.__init is not None:
             event_bus.add_listener(EVENT.On_Init, self.init)
@@ -27,6 +28,8 @@ class Strategy(object):
             event_bus.add_listener(EVENT.On_Order, self.handle_order)
         if self.__handle_trade is not None:
             event_bus.add_listener(EVENT.On_Trade, self.handle_trade)
+        if self.__handle_market_close is not None:
+            event_bus.add_listener(EVENT.On_Market_Close, self.handle_market_close)
         if self.__handle_open is not None:
             Environment.get_instance().scheduler.add_task(SchedulerTask(None,datetime.time(20,30),EVENT.On_Open))
             event_bus.add_listener(EVENT.On_Open, self.handle_open)
@@ -46,6 +49,10 @@ class Strategy(object):
     def handle_bar(self, event):
         self.__rebuild_event_data(event.data)
         self.__handle_bar(self.__user_context, event.data)
+    
+    def handle_market_close(self, event):
+        self.__rebuild_event_data(event.data)
+        self.__handle_market_close(self.__user_context, event.data)
 
     def handle_tick(self, event):
         self.__rebuild_event_data(event.data)
