@@ -19,20 +19,20 @@ def on_init(ctx):
 
     risk_ratio = risk['risk_ratio']
 
-    positions = ctx.get_positions()
+    # positions = ctx.get_positions()
 
-    position = ctx.get_position('rb2010.SHFE')
+    # position = ctx.get_position('rb2010.SHFE')
 
     # order =
     # ctx.insert_order('m2009.DCE',OrderSide.Sell,OrderType.MKT,Offset.Open,0,8)
     # order =
     # ctx.insert_order('m2009.DCE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,5)
 
-    order = ctx.insert_smart_order('c2009.DCE', -20)
+    # order = ctx.insert_smart_order('c2009.DCE', -20)
 
     id = ctx.get_strategy_id()
 
-    ctx.subscribe(('cu2010.SHFE','1m'),('rr2009.DCE','1m'),('rb2010.SHFE','1m'),('sc2009.INE','1m'),('rb2010.SHFE','TICK'))
+    ctx.subscribe(('cu2010.SHFE','1m'),('rr2009.DCE','1m'),('rb2010.SHFE','1m'),('sc2009.INE','1m'))
 
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
     conInfo = ctx.get_contract(ctx.domi_contract.symbol)
@@ -41,21 +41,21 @@ def on_init(ctx):
 
     last_ticks = ctx.get_last_ticks(ctx.domi_contract.symbol,100)
 
-    account = ctx.get_account()
+    # account = ctx.get_account()
 
-    orders = ctx.get_open_orders()
+    # orders = ctx.get_open_orders()
 
-    positions = ctx.get_positions()
+    # positions = ctx.get_positions()
 
-    trades = ctx.get_trades()
+    # trades = ctx.get_trades()
 
-    order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,3)
+    # order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,3)
 
-    order = ctx.insert_smart_order('rb2010.SHFE', 1, 3508)
+    # order = ctx.insert_smart_order('rb2010.SHFE', 1, 3508)
 
     #order1 = ctx.cancel_order(order)
 
-    order2 = ctx.get_order(order.order_id)
+    # order2 = ctx.get_order(order.order_id)
 
     bars1 = ctx.get_history_bars('rb2010.SHFE','1m','20200521','20200522')
 
@@ -69,40 +69,24 @@ def on_init(ctx):
 
     ctx.insert_func_at_time(run_time,time(13,49,0))
 
-    ctx.insert_func_at_time(run_time,datetime(2020,6,3,14,25,50),ctx)
+    ctx.insert_func_at_time(run_time,datetime(2020,6,4,10,35,50),ctx)
 
     pass
 
 def run_time(*args):
-    args[0][0].stop()
+    ctx = args[0][0]
+    ctx.unsubscribe(('rb2010.SHFE','TICK'))
+    logger.info('unsubscribe')
     
 def on_open(ctx):
-    ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
-    conInfo = ctx.get_contract(ctx.domi_contract.symbol)
-    ctx.lots = conInfo.lots
-    ctx.step = conInfo.step
-    ctx.subscribe((ctx.domi_contract,'1m'))
-    ctx.range = cal_range(ctx)
-    ctx.prepared = False
+    logger.info('on open raised')
     
 def on_close(ctx):
     ctx.last_domi = ctx.domi_contract
-    
-def cal_range(ctx):
-    last_bars = ctx.get_last_bars(ctx.domi_contract,'1d',300)
-    High = np.array([bar.high for bar in last_bars])
-    Low = np.array([bar.low for bar in last_bars])
-    Close = np.array([bar.close for bar in last_bars])
-    Range = talib.ATR(High,Low,Close,timeperiod=ctx.f1 - 1)[-1]
-    return Range
-    
-def change_contract(ctx):
-    lp = ctx.get_position(ctx.last_domi)
-    quantity = (lp.quantity - lp.frozen) * lp.OrderSide
-    if quantity:
-        ctx.insert_smart_order(ctx.last_domi,-quantity)
-        ctx.insert_smart_order(ctx.domi_contract,quantity)
-        ctx.unsubscribe((ctx.last_domi,'1m'))
+    logger.info('on close raised')
+
+def on_market_close(ctx,bar):
+    logger.info('on market close bar:{0},{1},{2}'.format(bar.symbol,bar.local_time,bar.close))
 
 def on_tick(ctx,tick):
     logger.info('tick:{0},{1},{2}'.format(tick.symbol,tick.local_time,tick.last))
@@ -115,35 +99,7 @@ def on_trade(ctx,trade):
     
 def on_bar(ctx,bar):
     logger.info('bar:{0},{1},{2}'.format(bar.symbol,bar.local_time,bar.close))
-    #if bar.symbol != ctx.domi_contract: return
-    #if not ctx.prepared:
-    #    if ctx.domi_contract != ctx.last_domi and ctx.last_domi:
-    #        change_contract(ctx)
-    #    ctx.open_price = bar.open
-    #    ctx.up = ctx.open_price + ctx.f2 * ctx.range
-    #    ctx.down = ctx.open_price - ctx.f3 * ctx.range
-    #    ctx.up = round(ctx.up / ctx.step) * ctx.step
-    #    ctx.down = round(ctx.down / ctx.step) * ctx.step
-    #    ctx.last_high = bar.high
-    #    ctx.last_low = bar.low
-    #    ctx.prepared = True
-    #    return
-    #else:
-    #    if not (bar.high > ctx.up and bar.low < ctx.down):
-    #        if ctx.last_high <= ctx.up and bar.open >= ctx.up:
-    #            acc = ctx.get_account()
-    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 *
-    #            ctx.bet_size)
-    #            if quantity:
-    #                ctx.insert_smart_order(ctx.domi_contract,quantity)
-    #        if ctx.last_low >= ctx.down and bar.open <= ctx.down:
-    #            acc = ctx.get_account()
-    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 *
-    #            ctx.bet_size)
-    #            if quantity:
-    #                ctx.insert_smart_order(ctx.domi_contract,-quantity)
-    #    ctx.last_high = bar.high
-    #    ctx.last_low = bar.low
+    
 config = {
     "runtime":"DEBUG",
     "run_type":"LIVE_TRADING",
